#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/preinstall.sh - pre-installation file for mini_httpd services on EIS/FAIR
#
# Copyright (c) 2003-2010  Marcus Herleb, info(at)herleb(dot).de
# Copyright (c) 2011-2020  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2003-05-02 mh
# Last Update:  $Id: preinstall.sh 71883 2020-01-11 19:49:55Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

#exec 2>/tmp/mini_httpd-preinstall-trace-$$.log
#set -x

module_name='mini_httpd'

configfile=/etc/config.d/${module_name}
configuserfile=/etc/config.d/${module_name}-access
installfile=/var/run/${module_name}.install
tarfile=/var/run/${module_name}.backup.tar.gz

# extract shared library file from archive
# to be able to use the myecho command
archivefile=`find /tmp -maxdepth 1 -type l -name "${module_name}.tar.*" ! -name "*.info" | head -n1`

if [ -n "${archivefile}" ]
then
    if [ -s "${archivefile}" ]
    then
        tar xjf ${archivefile} var/install/include/jedlib.${module_name} -C /

        srcfile=/var/install/include/jedlib.${module_name}
        destfile=/var/install/include/jedlib

        if [ -f ${srcfile} ]
        then
            if [ -f ${destfile} ]
            then
                srcver=`/bin/sh ${srcfile} version`
                destver=`/bin/sh ${destfile} version`

                if [ -n "${destver}" ]
                then
                    # version number exists - compare version numbers
                    if [ `echo "${srcver} > ${destver}" | bc` -eq 1 ]
                    then
                        # update file
                        echo "updating shared library file (${destver}->${srcver}) ..."
                        mv -v ${srcfile} ${destfile}
                    fi
                else
                    # no version number exists - update file
                    echo "updating shared library file ..."
                    mv -v ${srcfile} ${destfile}
                fi
            else
                # file doesn't exist - update file
                echo "updating shared library file ..."
                mv -v ${srcfile} ${destfile}
            fi
        fi
    fi
fi

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib
. /var/install/bin/config_shlib

myecho --pack ${module_name} --info "running preinstall.sh ..."

if [ -f /etc/init.d/${module_name} ]
then
    myecho --pack ${module_name} "stopping running processes ..."
    /etc/init.d/${module_name} stop
fi

# backup existing file
# override file mask for backup_config
fmask='[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]-[0-9][0-9]-[0-9][0-9]-[0-9][0-9]'

if [ -f ${configfile} ]
then
    # backup existing configuration file
    # don't directly use /var/install/bin/backup-file to prevent problems
    # caused by some of the legacy mini_httpd module packages where the
    # file name conventions are not followed properly
    backup_config ${module_name} ${configfile} '' quiet

    myecho --pack ${module_name} "saving previous configuration file to ${installfile} ..."
    cp ${configfile} ${installfile}

    # append user access configuration, if it exists
    if [ -f ${configuserfile} ]
    then
        {
            echo
            cat ${configuserfile}
        } >> ${installfile}
    fi
fi

myecho --pack ${module_name} "saving configuration data ... "
tar cfzl ${tarfile} /etc/httpd/* /var/install/menu/setup.services.mini_httpd.module.menu 2>/dev/null

# remove obsolete files
rm -f /etc/check.d/mini_httpd-access
rm -f /etc/default.d/mini_httpd-access
rm -f /etc/filelist.d/mini_httpd-files

# deinstall old software
myecho --pack ${module_name} "deinstalling previously installed software ..."
/usr/bin/eisman uninstall --update --auto --quiet ${module_name}

exit 0
