#!/bin/sh
#------------------------------------------------------------------------------
# /usr/local/bin/httpd-menu.sh - add/remove items from the httpd-menu
#
# Copyright (c) 2003-2010  Marcus Herleb, info(at)herleb(dot).de
# Copyright (c) 2011-2020  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2003-05-02 mh
# Last Update:  $Id: httpd-menu.sh 77935 2020-06-10 09:42:46Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

#exec 2>./mini_httpd-trace-$$.log
#set -x

action="$1"
link="$2"
name="$3"
section="${4:-Opt}"

menufile="/etc/httpd/menu"
tmpfile="/tmp/httpd-menu-$$.tmp"

# menue labels
# d - dummy entry
# e - label for menue entry
# t - label for menue section

case "$action" in
    add* )
        # check if menue section exists
        if [ -n "${section}" ]
        then
            if [ -f ${menufile} ]
            then
                # section information given, go on...
                grep "^t -[[:space:]]*${section}\$" ${menufile} > /dev/null 2>&1

                if [ $? -eq 1 ]
                then
                    # section doesn't exist, add it ...
                    echo "t - ${section}" >> ${menufile}
                fi
            else
                # file doesn't exist, create it ...
                echo "t - ${section}" > ${menufile}
            fi
        fi

        # check if menue entry exists
        grep -q "^e ${link} " ${menufile}

        if [ $? -ne 0 ]
        then
            echo "d - DUMMY" >> ${menufile}
            sed -e "/^t -[[:space:]]*${section}\$/,/^[td] / { /^\\([^td] \\|t -[[:space:]]*${section}\$\\)/ ! i\\" \
                -e "e ${link} ${name}" -e "}" ${menufile} > ${tmpfile}
            grep -v "d - DUMMY" ${tmpfile} > ${menufile}
            rm -f ${tmpfile}

            $0 sort
        fi
        ;;

    rem* )
        if [ -f ${menufile} ]
        then
            grep -v "^e ${link} " ${menufile} > ${tmpfile}
            cp ${tmpfile} ${menufile}
            rm -f ${tmpfile}
        fi
        ;;

    sort )
        if [ -f ${menufile} ]
        then
            cp ${menufile} ${menufile}.backup

            newfile=${menufile}-new
            rm -f ${newfile} ${tmpfile}

            while read line
            do
                set - ${line}

                mtype="$1"
                mfile="$2"
                mcomment="$3"

                while [ $# -gt 3 ]
                do
                    mcomment="${mcomment} $4"
                    shift
                done

                case ${mtype} in
                    t )
                        # table
                        if [ -f ${tmpfile} ]
                        then
                            cat ${tmpfile} | sort -t ' ' -k 3 >> ${newfile}
                            rm -f ${tmpfile}
                        fi

                        echo "t ${mfile} ${mcomment}" >> ${newfile}
                        ;;
                    e )
                        # entry
                        echo "e ${mfile} ${mcomment}" >> ${tmpfile}
                        ;;
                esac
            done < ${menufile}

            if [ -f ${tmpfile} ]
            then
                cat ${tmpfile} | sort -t ' ' -k 3 >> ${newfile}
                rm -f ${tmpfile}
            fi

            cp ${newfile} ${menufile}

            rm -f ${newfile}
        fi
        ;;

    * )
        echo "Usage: $0 add <link> <name> [section]"
        echo "       $0 rem <link>"
        echo "       $0 sort"
        exit 1
        ;;
esac

exit 0
